summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/forms/widgets/kexidbform.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/forms/widgets/kexidbform.cpp')
-rw-r--r--kexi/plugins/forms/widgets/kexidbform.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kexi/plugins/forms/widgets/kexidbform.cpp b/kexi/plugins/forms/widgets/kexidbform.cpp
index 17242953..88ddf93f 100644
--- a/kexi/plugins/forms/widgets/kexidbform.cpp
+++ b/kexi/plugins/forms/widgets/kexidbform.cpp
@@ -125,13 +125,13 @@ KexiDBForm::~KexiDBForm()
KexiDataAwareObjectInterface* KexiDBForm::dataAwareObject() const { return d->dataAwareObject; }
-//repaint all children widgets
+//tqrepaint all tqchildren widgets
static void repaintAll(TQWidget *w)
{
TQObjectList *list = w->queryList(TQWIDGET_OBJECT_NAME_STRING);
TQObjectListIt it(*list);
for (TQObject *obj; (obj=it.current()); ++it ) {
- TQT_TQWIDGET(obj)->repaint();
+ TQT_TQWIDGET(obj)->tqrepaint();
}
delete list;
}
@@ -148,7 +148,7 @@ void
KexiDBForm::drawRects(const TQValueList<TQRect> &list, int type)
{
TQPainter p;
- p.begin(TQT_TQPAINTDEVICE(this), true);
+ p.tqbegin(TQT_TQPAINTDEVICE(this), true);
bool unclipped = testWFlags( WPaintUnclipped );
setWFlags( WPaintUnclipped );
@@ -192,7 +192,7 @@ void
KexiDBForm::clearForm()
{
TQPainter p;
- p.begin(TQT_TQPAINTDEVICE(this), true);
+ p.tqbegin(TQT_TQPAINTDEVICE(this), true);
bool unclipped = testWFlags( WPaintUnclipped );
setWFlags( WPaintUnclipped );
@@ -216,7 +216,7 @@ KexiDBForm::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint &poi
toPoint = to->parentWidget()->mapTo(this, to->pos());
TQPainter p;
- p.begin(TQT_TQPAINTDEVICE(this), true);
+ p.tqbegin(TQT_TQPAINTDEVICE(this), true);
bool unclipped = testWFlags( WPaintUnclipped );
setWFlags( WPaintUnclipped );
@@ -234,7 +234,7 @@ KexiDBForm::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint &poi
TQPixmap pix2 = TQPixmap::grabWidget(to);
if((from != this) && (to != this))
- p.drawLine( from->parentWidget()->mapTo(this, from->geometry().center()), to->parentWidget()->mapTo(this, to->geometry().center()) );
+ p.drawLine( from->parentWidget()->mapTo(this, from->tqgeometry().center()), to->parentWidget()->mapTo(this, to->tqgeometry().center()) );
p.drawPixmap(fromPoint.x(), fromPoint.y(), pix1);
p.drawPixmap(toPoint.x(), toPoint.y(), pix2);
@@ -268,7 +268,7 @@ KexiDBForm::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint &poi
}
TQSize
-KexiDBForm::sizeHint() const
+KexiDBForm::tqsizeHint() const
{
//todo: find better size (user configured?)
return TQSize(400,300);
@@ -304,7 +304,7 @@ TQPtrList<TQWidget>* KexiDBForm::orderedDataAwareWidgets() const
void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
{
TQWidget *fromWidget = 0;
- //TQWidget *topLevelWidget = form->widget()->topLevelWidget();
+ //TQWidget *tqtopLevelWidget = form->widget()->tqtopLevelWidget();
//js form->updateTabStopsOrder(); //certain widgets can have now updated focusPolicy properties, fix this
uint numberOfDataAwareWidgets = 0;
// if (d->orderedFocusWidgets.isEmpty()) {
@@ -313,18 +313,18 @@ void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
if (it.current()->widget()->focusPolicy() & TQ_TabFocus) {
//this widget has tab focus:
it.current()->widget()->installEventFilter(this);
- //also filter events for data-aware children of this widget (i.e. KexiDBAutoField's editors)
- TQObjectList *children = it.current()->widget()->queryList(TQWIDGET_OBJECT_NAME_STRING);
- for (TQObjectListIt childrenIt(*children); childrenIt.current(); ++childrenIt) {
- // if (dynamic_cast<KexiFormDataItemInterface*>(childrenIt.current())) {
+ //also filter events for data-aware tqchildren of this widget (i.e. KexiDBAutoField's editors)
+ TQObjectList *tqchildren = it.current()->widget()->queryList(TQWIDGET_OBJECT_NAME_STRING);
+ for (TQObjectListIt tqchildrenIt(*tqchildren); tqchildrenIt.current(); ++tqchildrenIt) {
+ // if (dynamic_cast<KexiFormDataItemInterface*>(tqchildrenIt.current())) {
kexipluginsdbg << "KexiDBForm::updateTabStopsOrder(): also adding '"
- << childrenIt.current()->className() << " " << childrenIt.current()->name()
+ << tqchildrenIt.current()->className() << " " << tqchildrenIt.current()->name()
<< "' child to filtered widgets" << endl;
- //it.current()->widget()->installEventFilter(TQT_TQWIDGET(childrenIt.current()));
- childrenIt.current()->installEventFilter(this);
+ //it.current()->widget()->installEventFilter(TQT_TQWIDGET(tqchildrenIt.current()));
+ tqchildrenIt.current()->installEventFilter(this);
// }
}
- delete children;
+ delete tqchildren;
if (fromWidget) {
kexipluginsdbg << "KexiDBForm::updateTabStopsOrder() tab order: " << fromWidget->name()
<< " -> " << it.current()->widget()->name() << endl;
@@ -361,7 +361,7 @@ void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
}
fromWidget = it.current();
}
-// SET_FOCUS_USING_REASON(focusWidget(), TQFocusEvent::Tab);
+// SET_FOCUS_USING_REASON(tqfocusWidget(), TQFocusEvent::Tab);
}*/
}
@@ -399,7 +399,7 @@ bool KexiDBForm::eventFilter( TQObject * watched, TQEvent * e )
bool tab = ke->state() == Qt::NoButton && key == TQt::Key_Tab;
bool backtab = ((ke->state() == Qt::NoButton || ke->state() == TQt::ShiftButton) && key == TQt::Key_Backtab)
|| (ke->state() == TQt::ShiftButton && key == TQt::Key_Tab);
- TQObject *o = watched; //focusWidget();
+ TQObject *o = watched; //tqfocusWidget();
TQWidget* realWidget = dynamic_cast<TQWidget*>(o); //will beused below (for tab/backtab handling)
if (!tab && !backtab) {